@@ -3,16 +3,18 @@
 
 #include <algorithm>
 
+#include <QDate>
+#include <QMetaType>
+
 #include <CMulticalendar.h>
 #include <CCalendar.h>
 #include <CEvent.h>
 #include <CTodo.h>
 #include <CJournal.h>
+#include <CBdayEvent.h>
 
 #include "ComponentInstance.h"
 
-#include <QMetaType>
-
 Q_DECLARE_METATYPE (CEvent*)
 Q_DECLARE_METATYPE (CTodo*)
 Q_DECLARE_METATYPE (CJournal*)
@@ -213,6 +215,16 @@ namespace CWrapper
         return journal;
     }
 
+    inline CBdayEvent* details(CBdayEvent *event)
+    {
+        int error;
+        CCalendar *calendar = CMulticalendar::MCInstance()->getCalendarById(event->getCalendarId(), error);
+        event = reinterpret_cast<CBdayEvent*>(calendar->getBirthDayEvent(event->getId(), error));
+        if (event) event->setCalendarId(calendar->getCalendarId());
+        delete calendar;
+        return event;
+    }
+
     // Adapt the given string to be displayed in one line of a limited length.
     // The purpose of the limit is to prevent wasting too much time
     // on impractical amounts of data that cannot fit on the screen anyway.
@@ -221,6 +233,18 @@ namespace CWrapper
         return QString::fromUtf8(std_str.c_str(), qMin(std_str.length(), limit)).replace('\n', ' ');
     }
 
+    // Some additional processing for summaries
+    inline QString summary(CComponent *component, const QDate &date, size_t limit = 0)
+    {
+        QString summary = limit ? simplify(component->getSummary(), limit)
+                                : QString::fromUtf8(component->getSummary().c_str());
+
+        if (component->getType() == E_BDAY && (!limit || summary.size() < limit))
+            summary += " (" + QString::number(date.year() - component->getStatus()) + ")";
+
+        return summary;
+    }
+
     inline const char* calendarType(const int type)
     {
         switch (type)
